import React from 'react';
import { Button, ButtonProps } from '../buttons';

type TabTypes = 'inline' | 'rounded' | 'simple';

type ContextType = {
  tabType: TabTypes;
};
const TabContext = React.createContext<ContextType>({
  tabType: 'inline',
});

export const Tabs = (props: { children: React.ReactNode; tabType?: TabTypes }) => {
  const tabType = props.tabType || 'inline';
  let className = '';
  if (tabType === 'inline') {
    className = 'flex items-stretch divide-x divide-secondary-200 border-x border-secondary-200 overflow-x-auto -my-px';
  } else if (tabType === 'rounded') {
    className = 'flex gap-x-1  border-b border-secondary-300 mb-5';
  } else if (tabType === 'simple') {
    className = 'flex gap-x-1';
  }
  return (
    <TabContext.Provider value={{ tabType: tabType }}>
      <div className={className}>{props.children}</div>
    </TabContext.Provider>
  );
};

export const Tab = ({
  activeTab,
  text,
  className = '',
  ...props
}: ButtonProps & {
  activeTab: boolean;
  children?: React.ReactNode;
  text: string;
}) => {
  const context = React.useContext(TabContext);

  if (context.tabType === 'inline') {
    className += ` pl-2 pr-1 gap-1 relative h-full text-secondary-500 border-secondary-200 before:content-[''] 
    before:absolute before:left-0 before:bottom-0 before:h-[2px] before:w-full
    ${activeTab ? 'before:bg-primary-500 hover:bg-inherit' : 'before:bg-transparent hover:before:bg-secondary-300 hover:text-dark hover:bg-secondary-200'}`;
  } else if (context.tabType === 'rounded') {
    className += ` -mb-px py-4 px-4 text-sm  text-secondary-500 text-center border rounded-t-lg rounded-b-none 
    ${activeTab ? 'active text-secondary-950 border-l-secondary-300 border-r-secondary-300 border-t-secondary-300 border-b-white' : ''} 
    before:bg-transparent hover:before:bg-secondary-300 hover:bg-secondary-200`;
  } else if (context.tabType === 'simple') {
    className += ` ${activeTab ? 'active bg-secondary-200 hover:bg-secondary-300' : 'hover:bg-secondary-100'}`;
  }

  return (
    <div className={`btn btn-ghost btn-xs rounded-none ${className}`} {...props}>
      <span>{text}</span>

      {props.children}
    </div>
  );
};
